"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
function generateDocgenCodeBlock(_a) {
    var filename = _a.filename, source = _a.source, componentDocs = _a.componentDocs, docgenCollectionName = _a.docgenCollectionName, setDisplayName = _a.setDisplayName;
    var relativeFilename = path_1.default
        .relative("./", path_1.default.resolve("./", filename))
        .replace(/\\/g, "/");
    var codeToInsertComponentDocs__docgenInfo = componentDocs
        .map(function (componentDoc) {
        var descriptionValue = JSON.stringify(componentDoc.description);
        var descriptionLine = descriptionValue
            ? "description: " + descriptionValue
            : undefined;
        var propsValue = JSON.stringify(componentDoc.props);
        var propsLine = propsValue ? "props: " + propsValue : undefined;
        var dislayNameLine = "displayName: \"" + componentDoc.displayName + "\"";
        var lines = [descriptionLine, propsLine, dislayNameLine].filter(function (line) { return line !== undefined; });
        var globalCollectionCode = docgenCollectionName
            ? getCodeToInsertDocgenIntoGlobalCollection(componentDoc.displayName, docgenCollectionName, relativeFilename)
            : "";
        var setDisplayNameCode = setDisplayName
            ? ("\n  // @ts-ignore\n  " + componentDoc.displayName + ".displayName = \"" + componentDoc.displayName + "\"\n          ").trim()
            : "";
        return ("\n  // @ts-ignore\n  " + componentDoc.displayName + ".__docgenInfo = {\n      " + lines.join(",\n      ") + "\n  };\n  " + [globalCollectionCode, setDisplayNameCode]
            .filter(function (item) { return item !== undefined; })
            .join("\n  ") + "\n").trim();
    })
        .join("\n");
    return ("\n" + source + "\ntry {\n" + codeToInsertComponentDocs__docgenInfo + "\n} catch {};\n").trim();
}
exports.default = generateDocgenCodeBlock;
/**
 * Adds a component's docgen info to the global docgen collection.
 *
 * ```
 * if (typeof STORYBOOK_REACT_CLASSES !== "undefined") {
 *   STORYBOOK_REACT_CLASSES["src/.../SimpleComponent.tsx"] = {
 *     name: "SimpleComponent",
 *     docgenInfo: SimpleComponent.__docgenInfo,
 *     path: "src/.../SimpleComponent.tsx",
 *   };
 * }
 * ```
 *
 * @param componentDocAccess Component doc.
 * @param docgenCollectionName Global docgen collection variable name.
 * @param relativeFilename Relative file path of the component source file.
 */
function getCodeToInsertDocgenIntoGlobalCollection(componentDocDisplayName, docgenCollectionName, relativeFilename) {
    var globalCollectionKey = relativeFilename + "#" + componentDocDisplayName;
    return ("\n  // @ts-ignore\n  if (typeof " + docgenCollectionName + " !== \"undefined\") {\n    // @ts-ignore\n    " + docgenCollectionName + "['" + globalCollectionKey + "'] = " + componentDocDisplayName + ".__docgenInfo;\n  }\n").trim();
}
//# sourceMappingURL=generateDocgenCodeBlock.js.map